# ASN.1 module IMZM-PDU-Descriptions
 OID: _{ itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (103724) imzm (1) version (1) }_
TEST!!! Specification of the Interference Management Zone Message ETSI TS 103 724
Latest version available at https://forge.etsi.org/rep/ITS/asn1/imzm_ts103724

## Imports:
 * **[ITS-Container](ITS-Container.md)** *{ itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (102894) cdd (2) version (2) }*<br/>
   Include ETSI TS 102 894-2
   Include references from https://forge.etsi.org/rep/ITS/asn1/cdd_ts102894_2/blob/master/ITS-Container.asn

 * **[CAM-PDU-Descriptions](CAM-PDU-Descriptions.md)** *{ itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) en (302637) cam (2) version (2) }*<br/>
   Include ETSI EN 302 637-2
   Include references from https://forge.etsi.org/rep/ITS/asn1/cam_en302637_2/blob/master/CAM-PDU-Descriptions.asn

 * **[VAM-Temp-Imports](VAM-Temp-Imports.md)** *{ itu-t(0) identified-organization(4) etsi(0) itsDomain(5) wg1(1) ts(103300) temp-imports(255) version1(1) }*<br/>
   Include ETSI TS 103 300-3
   Import from `VAM-Temp-Imports` will be changed to CDD ETSI TS 102 894-2 Release 2 when available
   Include references from https://forge.etsi.org/rep/ITS/asn1/vam-ts103300_3/blob/master/VAM-Temp-Imports.asn
   This is temporary.** These data types shall be defined in the next verion of CDD

## Data Elements:
### <a name="IMZM"></a>DF: Interference Management Zone Message Root


This DF includes DEs for the IMZM `protocolVersion`, the IMZ message type identifier `messageID`
and the station identifier `stationID` of the originating ITS-S.

Fields:
* header [**ItsPduHeader**](ITS-Container.md#ItsPduHeader) <br>
   
   - The DE `protocolVersion` is used to select the appropriate protocol decoder at the receiving
   ITS-S. For TS 103 724 V2.1.1, the value of the DE `protocolVersion` shall be set to 1.
   - The DE `messageID` shall be harmonized with other V2X message identifier definitions.
   For IMZM, the DE messageID shall be set to `imzm(15)`.
* imzm [**InterferenceManagementZoneMessage**](#InterferenceManagementZoneMessage) <br>
```asn1
IMZM ::= SEQUENCE {
   header ItsPduHeader,
   imzm InterferenceManagementZoneMessage
}
```

### <a name="InterferenceManagementZoneMessage"></a>DF: Interference Management Zone Message


This is the actual IMZM Payload. It shall include the time stamp of the IMZM and the applicable
containers of type `BasicContainer` and `ImzmContainer`.

Fields:
* generationDeltaTime [**GenerationDeltaTime**](CAM-PDU-Descriptions.md#GenerationDeltaTime) <br>
* imzmParameters [**ImzmParameters**](#ImzmParameters) <br>
```asn1
InterferenceManagementZoneMessage ::= SEQUENCE {
   generationDeltaTime GenerationDeltaTime, 
   imzmParameters ImzmParameters
}
```

### <a name="ImzmParameters"></a>DF: IMZM Parameters


The sequence of containers in the IMZM. Other containers may be added in the future.

Fields:
* basicContainer [**BasicContainer**](CAM-PDU-Descriptions.md#BasicContainer) <br>
   
   imported from CAM-PDU-Descriptions
* imzmContainer [**ImzmContainer**](#ImzmContainer) <br>
   
   container specific to the IMZM
```asn1
ImzmParameters ::= SEQUENCE {
    basicContainer BasicContainer, 
    imzmContainer ImzmContainer,
   ...
}
```

### <a name="ImzmContainer"></a>DF: IMZM Container


The IMZM container includes a sequence of up to 16 interference management zones.
For each interference management zones, it contains a sequence of interference
management zones per channel together with their characteristics.

Fields:
* interferenceManagementZones [**InterferenceManagementZones**](#InterferenceManagementZones) <br>
   
   mapped to the DF_ProtectedCommunicationZone in ETSI TS 102 894-2
```asn1
ImzmContainer ::= SEQUENCE {
    interferenceManagementZones InterferenceManagementZones,
    ...
}
```

### <a name="InterferenceManagementZones"></a>DF: List of Interference Management Zones


A list of up to 16 interference management zones.
EXAMPLE**: An interference management communication zone may be defined around a
CEN DSRC road side equipment or an urban rail operational area.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: [Infrastructure information](#Infrastructure+information) [Communication information](#Communication+information) 




```asn1
InterferenceManagementZones ::= SEQUENCE (SIZE(1..16), ...) OF InterferenceManagementZone
```

### <a name="InterferenceManagementZone"></a>DF: Interference Management Zone


Describes a zone of interferenceManagement inside which the ITS communication should
be restricted.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: [Infrastructure information](#Infrastructure+information) [Communication information](#Communication+information)

Fields:
* zoneDefinition [**ZoneDefinition**](#ZoneDefinition) <br>
* interferenceManagementInfo [**InterferenceManagementInfo**](#InterferenceManagementInfo) <br>
```asn1
InterferenceManagementZone ::= SEQUENCE {
	zoneDefinition             ZoneDefinition,
	interferenceManagementInfo InterferenceManagementInfo
}
```

### <a name="ZoneDefinition"></a>DF: Zone Definition


Describes the zone where band sharing occurs. When reusing CDD Rel.1 types, names are unchanged.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: [Infrastructure information](#Infrastructure+information) [Communication information](#Communication+information)

Fields:
* interferenceManagementZoneLatitude [**Latitude**](ITS-Container.md#Latitude) <br>
   
   Latitude of the centre point of the interference management zone.
* interferenceManagementZoneLongitude [**Longitude**](ITS-Container.md#Longitude) <br>
   
   Longitude of the centre point of the interference management zone.
* interferenceManagementZoneRadius [**ProtectedZoneRadius**](ITS-Container.md#ProtectedZoneRadius)  OPTIONAL<br>
   
   Radius of the interference management zone in metres.
   This DE is present if the data is available
* interferenceManagementZoneID [**ProtectedZoneID**](ITS-Container.md#ProtectedZoneID)  OPTIONAL<br>
   
   Identification of the interference management zone.
   This DE is present if the data is available.
* interferenceManagementZoneShape [**InterferenceManagementZoneShape**](#InterferenceManagementZoneShape)  OPTIONAL<br>
   
   Shape of the interference management zone.
   This DF is present if the data is available.
```asn1
ZoneDefinition::= SEQUENCE{     
    interferenceManagementZoneLatitude   Latitude, 
    interferenceManagementZoneLongitude  Longitude, 
    interferenceManagementZoneRadius     ProtectedZoneRadius OPTIONAL, 
    interferenceManagementZoneID         ProtectedZoneID OPTIONAL, 
    interferenceManagementZoneShape      InterferenceManagementZoneShape OPTIONAL,
    ...
}
```

### <a name="InterferenceManagementInfo"></a>DF: Interference Management Information


A list of up to 16 definitions containing which interference management may be applied in the zone,
per affected frequency channels.

Note**: in the case where no mitigation should be applied by the ITS-S, this is indicated
by the value of interferenceManagementMitigationType set to unavailable.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: [Infrastructure information](#Infrastructure+information) [Communication information](#Communication+information) 




```asn1
InterferenceManagementInfo::= SEQUENCE (SIZE(1..16,...)) OF InterferenceManagementInfoPerChannel
```

### <a name="InterferenceManagementInfoPerChannel"></a>DF: Interference Management Information Per Channel 


A break up of the interference management information per affected frequency channels.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: [Infrastructure information](#Infrastructure+information) [Communication information](#Communication+information)

Fields:
* interferenceManagementChannel [**InterferenceManagementChannel**](#InterferenceManagementChannel) <br>
   
   Characteritics of the frequency channel for which the zone
   should be applied interference management
* interferenceManagementZoneType [**InterferenceManagementZoneType**](#InterferenceManagementZoneType) <br>
   
   Type of the interference management zone.
* interferenceManagementMitigationType [**InterferenceManagementMitigationType**](#InterferenceManagementMitigationType)  OPTIONAL<br>
   
   Type of the mitigation to be used in the interference management zone.
* expiryTime [**TimestampIts**](ITS-Container.md#TimestampIts)  OPTIONAL<br>
   
   Time at which the validity of the interference management communication zone will expire.
   This DE is present when the interference management is temporarily valid
```asn1
InterferenceManagementInfoPerChannel ::= SEQUENCE {
    interferenceManagementChannel         InterferenceManagementChannel,
    interferenceManagementZoneType        InterferenceManagementZoneType,
    interferenceManagementMitigationType  InterferenceManagementMitigationType OPTIONAL,
    expiryTime                            TimestampIts OPTIONAL, 
    ...
}
```

### <a name="InterferenceManagementChannel"></a>DF: InterferenceManagementChannel


Indicates which shared frequency channel should be applied interference management in the zone.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: [Communication information](#Communication+information)

Fields:
* centreFrequency **INTEGER**  (1 .. 99999)<br>
    frequency of the channel
   @unit: 10exp+2 Hz (where exp is exponent)
* channelWidth **INTEGER**  (0 .. 9999)<br>
    of the channel
   @unit: 10exp Hz (where exp is exponent)
* exponent **INTEGER**  (0 .. 15)<br>
    of the power of 10
   @unit: N/A
```asn1
InterferenceManagementChannel ::= SEQUENCE {
    centreFrequency INTEGER (1 .. 99999),
    channelWidth    INTEGER (0 .. 9999),
    exponent        INTEGER (0 .. 15) 
}
```

### <a name="InterferenceManagementZoneType"></a>DE: InterferenceManagementZoneType


defines the type of an interference management zone, so that an ITS-S can
assert the actions to do while passing by such zone (e.g. reduce the transmit
power in case of a DSRC tolling station).
@unit: N/A

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: [Communication information](#Communication+information) 




```asn1
InterferenceManagementZoneType ::= ENUMERATED {
    permanentCenDsrcTolling(0), 
    temporaryCenDsrcTolling(1), 
    unavailable(2),             
    urbanRail(3),               
    satelliteStation(4),        
    fixedLinks(5),              
    ...
}
```

### <a name="InterferenceManagementMitigationType"></a>DF: Mitigation type in the interference management zone


Information and commands defining the required mitigation type the
receiving ITS-S has to use in the defined interference management zone.
It indicates the type of mitigation and the parameters to be used to protect the
potential victim in the interference management zone per channel access technology class.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: [Communication information](#Communication+information)

Fields:
* unavailable **NULL** <br>
    is the default value to be used when data is not available.
* mitigationForTechnologies [**MitigationForTechnologies**](#MitigationForTechnologies) <br>
```asn1
InterferenceManagementMitigationType ::= CHOICE {
    unavailable   NULL,   
    mitigationForTechnologies MitigationForTechnologies
}
```

### <a name="MitigationForTechnologies"></a>DF: Mitigation type container for the different channel access technology classes 


Class of parameters for the relevant channel access technology classes,
as specified in ETSI TS 103 724, clause 7.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: [Communication information](#Communication+information) 




```asn1
MitigationForTechnologies ::= SEQUENCE (SIZE(1..8)) OF MitigationPerTechnologyClass
```

### <a name="MitigationPerTechnologyClass"></a>DF: Mitigation type container per channel access technology class 


Class of parameters for the specific technology indicated in the container.
All parameters are optional, as they may not apply to some of the technologies or
interference management zone types. Specification details are in ETSI TS 103 724, clause 7.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: [Communication information](#Communication+information)

Fields:
* accessTechnologyClass [**AccessTechnologyClass**](#AccessTechnologyClass) <br>
    access technology in which this mitigation is applied.
   @unit: N/A
* lowDutyCycle **INTEGER**  (0 .. 10000) OPTIONAL<br>
    cycle limit.
   @unit: 0.01% steps
* powerReduction **INTEGER**  (0 .. 30) OPTIONAL<br>
    reduction.
   @unit: dB
* dmcToffLimit **INTEGER**  (0 .. 1200) OPTIONAL<br>
    time limit as defined in ETSI TS 103 175.
   @unit: ms
* dmcTonLimit **INTEGER**  (0 .. 20) OPTIONAL<br>
    duration limit, as defined in ETSI EN 302 571.
   @unit: ms
```asn1
MitigationPerTechnologyClass ::= SEQUENCE {
   accessTechnologyClass  AccessTechnologyClass, 
   lowDutyCycle  INTEGER (0 .. 10000) OPTIONAL, 
   powerReduction INTEGER (0 .. 30) OPTIONAL,
   dmcToffLimit   INTEGER (0 .. 1200) OPTIONAL,   
   dmcTonLimit   INTEGER (0 .. 20) OPTIONAL,   
   ...
}
```

### <a name="AccessTechnologyClass"></a>DE: channel access technology class 


Access technology to which the mitigation type applies.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: [Communication information](#Communication+information) 




```asn1
AccessTechnologyClass ::= ENUMERATED {
   any(0),         
   itsg5Class(1),  
   ltev2xClass(2), 
   nrv2xClass(3),  
   ...
}
```

### <a name="InterferenceManagementZoneShape"></a>DF: Shape of the interference management zone


Bounding box of an interference management  zone

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: [GeoReference information](#GeoReference+information)

Fields:
* rectangle [**AreaRectangle**](VAM-Temp-Imports.md#AreaRectangle) <br>
* circle [**AreaCircular**](VAM-Temp-Imports.md#AreaCircular) <br>
* polygon [**AreaPolygon**](VAM-Temp-Imports.md#AreaPolygon) <br>
* ellipse [**AreaEllipse**](#AreaEllipse) <br>
```asn1
InterferenceManagementZoneShape::= CHOICE {
   rectangle    AreaRectangle, 
   circle       AreaCircular,  
   polygon      AreaPolygon,   
   ellipse      AreaEllipse,   
   ...
}
```

### <a name="AreaEllipse"></a>DF: Area Ellipse


Area Ellipse copied from CPM TR 103 562. Will be removed when CDD Release 2 is available.
Describes an elliptical area. The ellipse is centred about the reference point
of the ITS-S or about the nodeCenterPoint (if provided).

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: [GeoReference information](#GeoReference+information)

Fields:
* nodeCenterPoint [**OffsetPoint**](VAM-Temp-Imports.md#OffsetPoint)  OPTIONAL<br>
   
   Optional offset point about which the ellipse is centred with respect to the reference
   position of the ITS-S.
* semiMajorRangeLength [**SemiRangeLength**](VAM-Temp-Imports.md#SemiRangeLength) <br>
   
   Minor radius of the ellipse.
* semiMinorRangeLength [**SemiRangeLength**](VAM-Temp-Imports.md#SemiRangeLength) <br>
   
   Major radius of the ellipse.
* semiMajorRangeOrientation [**WGS84AngleValue**](VAM-Temp-Imports.md#WGS84AngleValue) <br>
   
   Orientation of the semiMajorRangeLength of the ellipse in the WGS84 coordinate system.
```asn1
AreaEllipse  ::= SEQUENCE {
    nodeCenterPoint             OffsetPoint OPTIONAL,
    semiMajorRangeLength        SemiRangeLength,
    semiMinorRangeLength        SemiRangeLength,
    semiMajorRangeOrientation   WGS84AngleValue
}
```



